package com.benyanyi.datelib;

import android.content.Context;
import android.graphics.drawable.ColorDrawable;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.PopupWindow;
import android.widget.TextView;

import com.benyanyi.datelib.config.SelectType;
import com.benyanyi.datelib.wheelview.AbstractWheelTextAdapter1;
import com.benyanyi.datelib.wheelview.OnWheelChangedListener;
import com.benyanyi.datelib.wheelview.OnWheelScrollListener;
import com.benyanyi.datelib.wheelview.WheelView;

import org.json.JSONObject;

import java.util.ArrayList;
import java.util.Calendar;

/**
 * @author yanyi
 */


public class SelectData extends PopupWindow implements View.OnClickListener {
    private static final String TAG = "SelectData";

    private WheelView wvYear;
    private WheelView wvMonth;
    private WheelView wvDay;
    private WheelView wvHour;
    private WheelView wvMinute;
    private View lySelectDate;
    private View lySelectDateChild;
    private TextView btnSure;
    private TextView btnCancel;

    private LinearLayout hourContainer, minuteContainer;

    private Context context;
    private JSONObject mJsonObj;

    private String[] mYearDatas, mMonthDatas, mDayDatas, mHourDatas, mMinuteDatas;


    private DateTextAdapter yearAdapter;
    private DateTextAdapter monthAdapter;
    private DateTextAdapter dayAdapter;
    private DateTextAdapter hourAdapter;
    private DateTextAdapter minuteAdapter;

    private SelectType selectType;
    private String strYear;
    private String strMonth;
    private String strDay;
    private String strHour;
    private String strMinute;
    private OnDateClickListener onDateClickListener;

    private int maxSize = 14;
    private int minSize = 12;
    private Calendar calendar = Calendar.getInstance();

    public SelectData(final Context context) {
        this(context, SelectType.NONE);
    }

    /**
     * 设置SelectPicPopupWindow弹出窗体动画效果
     * this.setAnimationStyle(R.style.AnimBottom);
     *
     * @param context
     * @param selectType
     */
    public SelectData(final Context context, SelectType selectType) {
        super(context);
        this.context = context;
        this.selectType = selectType;
        View view = View.inflate(context, R.layout.select_date_pop_layout, null);

        wvYear = view.findViewById(R.id.wv_date_year);
        wvMonth = view.findViewById(R.id.wv_date_month);
        wvDay = view.findViewById(R.id.wv_date_day);
        wvHour = view.findViewById(R.id.wv_date_hour);
        wvMinute = view.findViewById(R.id.wv_date_minute);
        lySelectDate = view.findViewById(R.id.select_date);
        lySelectDateChild = view.findViewById(R.id.select_date_child);
        btnSure = view.findViewById(R.id.btn_myinfo_sure);
        btnCancel = view.findViewById(R.id.btn_myinfo_cancel);

        hourContainer = view.findViewById(R.id.hour_container);
        minuteContainer = view.findViewById(R.id.minute_container);
        switch (selectType) {
            case NONE:
            default:
                hourContainer.setVisibility(View.VISIBLE);
                minuteContainer.setVisibility(View.VISIBLE);
                break;
            case HOUR:
                hourContainer.setVisibility(View.GONE);
            case MIN:
                minuteContainer.setVisibility(View.GONE);
                break;
        }

        //设置SelectPicPopupWindow的View
        this.setContentView(view);
        //设置SelectPicPopupWindow弹出窗体的宽
        this.setWidth(ViewGroup.LayoutParams.MATCH_PARENT);
        //设置SelectPicPopupWindow弹出窗体的高
        this.setHeight(ViewGroup.LayoutParams.MATCH_PARENT);
        //设置SelectPicPopupWindow弹出窗体可点击
        this.setFocusable(true);
        //实例化一个ColorDrawable颜色为半透明
        ColorDrawable dw = new ColorDrawable(0xb0000000);
        //设置SelectPicPopupWindow弹出窗体的背景
        this.setBackgroundDrawable(dw);

        lySelectDateChild.setOnClickListener(this);
        btnSure.setOnClickListener(this);
        btnCancel.setOnClickListener(this);

        initDates();

        yearAdapter = new DateTextAdapter(context, mYearDatas, Integer.parseInt(strYear) - calendar.get(Calendar.YEAR) + 100, maxSize, minSize);
        wvYear.setVisibleItems(5);
        wvYear.setViewAdapter(yearAdapter);
        wvYear.setCurrentItem(Integer.parseInt(strYear) - calendar.get(Calendar.YEAR) + 100);


        monthAdapter = new DateTextAdapter(context, mMonthDatas, Integer.parseInt(strMonth) - 1, maxSize, minSize);
        wvMonth.setVisibleItems(5);
        wvMonth.setViewAdapter(monthAdapter);
        wvMonth.setCurrentItem(Integer.parseInt(strMonth) - 1);

        dayAdapter = new DateTextAdapter(context, mDayDatas, Integer.parseInt(strDay) - 1, maxSize, minSize);
        wvDay.setVisibleItems(5);
        wvDay.setViewAdapter(dayAdapter);
        wvDay.setCurrentItem(Integer.parseInt(strDay) - 1);

        hourAdapter = new DateTextAdapter(context, mHourDatas, Integer.parseInt(strHour), maxSize, minSize);
        wvHour.setVisibleItems(5);
        wvHour.setViewAdapter(hourAdapter);
        wvHour.setCurrentItem(Integer.parseInt(strHour));

        minuteAdapter = new DateTextAdapter(context, mMinuteDatas, Integer.parseInt(strMinute), maxSize, minSize);
        wvMinute.setVisibleItems(5);
        wvMinute.setViewAdapter(minuteAdapter);
        wvMinute.setCurrentItem(Integer.parseInt(strMinute));

        wvYear.addChangingListener(new OnWheelChangedListener() {

            @Override
            public void onChanged(WheelView wheel, int oldValue, int newValue) {
                // TODO Auto-generated method stub
                String currentText = (String) yearAdapter.getItemText(wheel.getCurrentItem());
                strYear = currentText;
                setTextViewSize(currentText, yearAdapter);


                mDayDatas = getDays(Integer.parseInt(strYear), Integer.parseInt(strMonth));
                dayAdapter = new DateTextAdapter(context, mDayDatas, 0, maxSize, minSize);
                wvDay.setVisibleItems(5);
                wvDay.setViewAdapter(dayAdapter);
                wvDay.setCurrentItem(0);
                setTextViewSize("0", dayAdapter);
            }
        });

        wvYear.addScrollingListener(new OnWheelScrollListener() {

            @Override
            public void onScrollingStarted(WheelView wheel) {
                // TODO Auto-generated method stub

            }

            @Override
            public void onScrollingFinished(WheelView wheel) {
                // TODO Auto-generated method stub
                String currentText = (String) yearAdapter.getItemText(wheel.getCurrentItem());
                setTextViewSize(currentText, yearAdapter);
            }
        });

        wvMonth.addChangingListener(new OnWheelChangedListener() {

            @Override
            public void onChanged(WheelView wheel, int oldValue, int newValue) {
                // TODO Auto-generated method stub
                String currentText = (String) monthAdapter.getItemText(wheel.getCurrentItem());
                strMonth = currentText;
                setTextViewSize(currentText, monthAdapter);


                mDayDatas = getDays(Integer.parseInt(strYear), Integer.parseInt(strMonth));
                dayAdapter = new DateTextAdapter(context, mDayDatas, 0, maxSize, minSize);
                wvDay.setVisibleItems(5);
                wvDay.setViewAdapter(dayAdapter);
                wvDay.setCurrentItem(0);
                setTextViewSize("0", dayAdapter);


            }
        });

        wvMonth.addScrollingListener(new OnWheelScrollListener() {

            @Override
            public void onScrollingStarted(WheelView wheel) {
                // TODO Auto-generated method stub

            }

            @Override
            public void onScrollingFinished(WheelView wheel) {
                // TODO Auto-generated method stub
                String currentText = (String) monthAdapter.getItemText(wheel.getCurrentItem());
                setTextViewSize(currentText, monthAdapter);
            }
        });

        wvDay.addChangingListener(new OnWheelChangedListener() {

            @Override
            public void onChanged(WheelView wheel, int oldValue, int newValue) {
                // TODO Auto-generated method stub
                String currentText = (String) dayAdapter.getItemText(wheel.getCurrentItem());
                strDay = currentText;
                setTextViewSize(currentText, dayAdapter);
            }
        });

        wvDay.addScrollingListener(new OnWheelScrollListener() {

            @Override
            public void onScrollingStarted(WheelView wheel) {
                // TODO Auto-generated method stub

            }

            @Override
            public void onScrollingFinished(WheelView wheel) {
                // TODO Auto-generated method stub
                String currentText = (String) dayAdapter.getItemText(wheel.getCurrentItem());
                setTextViewSize(currentText, dayAdapter);
            }
        });


        wvHour.addChangingListener(new OnWheelChangedListener() {

            @Override
            public void onChanged(WheelView wheel, int oldValue, int newValue) {
                // TODO Auto-generated method stub
                String currentText = (String) hourAdapter.getItemText(wheel.getCurrentItem());
                strMinute = currentText;
                setTextViewSize(currentText, hourAdapter);
            }
        });

        wvHour.addScrollingListener(new OnWheelScrollListener() {

            @Override
            public void onScrollingStarted(WheelView wheel) {
                // TODO Auto-generated method stub

            }

            @Override
            public void onScrollingFinished(WheelView wheel) {
                // TODO Auto-generated method stub
                String currentText = (String) hourAdapter.getItemText(wheel.getCurrentItem());
                setTextViewSize(currentText, hourAdapter);
            }
        });
        wvMinute.addChangingListener(new OnWheelChangedListener() {

            @Override
            public void onChanged(WheelView wheel, int oldValue, int newValue) {
                // TODO Auto-generated method stub
                String currentText = (String) minuteAdapter.getItemText(wheel.getCurrentItem());
                strMinute = currentText;
                setTextViewSize(currentText, minuteAdapter);
            }
        });

        wvMinute.addScrollingListener(new OnWheelScrollListener() {

            @Override
            public void onScrollingStarted(WheelView wheel) {
                // TODO Auto-generated method stub

            }

            @Override
            public void onScrollingFinished(WheelView wheel) {
                // TODO Auto-generated method stub
                String currentText = (String) minuteAdapter.getItemText(wheel.getCurrentItem());
                setTextViewSize(currentText, minuteAdapter);
            }
        });

    }


    private class DateTextAdapter extends AbstractWheelTextAdapter1 {
        String[] list;

        protected DateTextAdapter(Context context, String[] list, int currentItem, int maxsize, int minsize) {
            super(context, R.layout.item_date, NO_RESOURCE, currentItem, maxsize, minsize);
            this.list = list;
            setItemTextResource(R.id.tempValue);
        }

        @Override
        public View getItem(int index, View cachedView, ViewGroup parent) {
            View view = super.getItem(index, cachedView, parent);
            return view;
        }

        @Override
        public int getItemsCount() {
            return list.length;
        }

        @Override
        protected CharSequence getItemText(int index) {
            // if (getItemsCount() == 0) return "";
            return list[index];
        }
    }

    /**
     * 设置字体大小
     *
     * @param currieItemText
     * @param adapter
     */
    public void setTextViewSize(String currieItemText, DateTextAdapter adapter) {
        ArrayList<View> arrayList = adapter.getTestViews();
        int size = arrayList.size();
        String currentText;
        for (int i = 0; i < size; i++) {
            TextView textView = (TextView) arrayList.get(i);
            currentText = textView.getText().toString();
            if (currieItemText.equals(currentText)) {
                textView.setTextSize(14);
            } else {
                textView.setTextSize(12);
            }
        }
    }

    public void setDateClickListener(OnDateClickListener onDateClickListener) {

        this.onDateClickListener = onDateClickListener;
    }

    @Override
    public void onClick(View v) {
        // TODO Auto-generated method stub
        if (v == btnSure) {
            if (onDateClickListener != null) {
                onDateClickListener.onClick(strYear, strMonth, strDay, strHour, strMinute);
            }
        } else if (v == btnCancel) {

        } else if (v == lySelectDateChild) {
            return;
        } else {
//			dismiss();
        }
        dismiss();
    }

    /**
     * 回调接口
     *
     * @author Administrator
     */
    public interface OnDateClickListener {
        /**
         * 点击回调
         *
         * @param year
         * @param month
         * @param day
         * @param hour
         * @param minute
         */
        void onClick(String year, String month, String day, String hour, String minute);
    }

    private void initDates() {
        int year, month, day, hour, minute;

        year = calendar.get(Calendar.YEAR);
        month = calendar.get(Calendar.MONTH) + 1;
        day = calendar.get(Calendar.DATE);
        hour = calendar.get(Calendar.HOUR_OF_DAY);
        minute = calendar.get(Calendar.MINUTE);
        strYear = String.valueOf(year);
        strMonth = (month < 10 ? "0" : "") + String.valueOf(month);
        strDay = (day < 10 ? "0" : "") + String.valueOf(day);
        switch (selectType) {
            case NONE:
            default:
                strHour = (hour < 10 ? "0" : "") + String.valueOf(hour);
                strMinute = (minute < 10 ? "0" : "") + String.valueOf(minute);
                break;
            case HOUR:
                strHour = "00";
                strMinute = "00";
                break;
            case MIN:
                strHour = (hour < 10 ? "0" : "") + String.valueOf(hour);
                strMinute = "00";
                break;
        }
        mYearDatas = new String[150];
        int i1 = 100;
        int i2 = 50;
        for (int i = year - i1, j = 0; i < year + i2; i++, j++) {
            mYearDatas[j] = i + "";
        }
        mMonthDatas = new String[12];
        int i3 = 12;
        for (int i = 0; i < i3; i++) {
            if (i < 9) {
                mMonthDatas[i] = "0" + (i + 1) + "";
            } else {
                mMonthDatas[i] = i + 1 + "";
            }

        }
        int count = calendar.getActualMaximum(Calendar.DAY_OF_MONTH);

        mDayDatas = new String[count];
        for (int i = 0; i < count; i++) {
            if (i < 9) {
                mDayDatas[i] = "0" + (i + 1);
            } else {
                mDayDatas[i] = i + 1 + "";
            }

        }
        mHourDatas = new String[24];
        int i4 = 24;
        for (int i = 0; i < i4; i++) {
            if (i < 10) {
                mHourDatas[i] = "0" + i;
            } else {
                mHourDatas[i] = i + "";
            }

        }
        int i5 = 60;
        mMinuteDatas = new String[60];
        for (int i = 0; i < i5; i++) {
            if (i < 10) {
                mMinuteDatas[i] = "0" + i;
            } else {
                mMinuteDatas[i] = i + "";
            }

        }
    }

    private String[] getDays(int year, int month) {
        String[] datas;
        Calendar newCal = Calendar.getInstance();
        // newCal.s
        newCal.set(Calendar.YEAR, year);
        newCal.set(Calendar.MONTH, month - 1);
        int count = newCal.getActualMaximum(Calendar.DAY_OF_MONTH);

        Log.e(TAG, "getDays: " + year + ":" + month + ":" + count);
        datas = new String[count];
        for (int i = 0; i < count; i++) {
            if (i < 9) {
                datas[i] = "0" + (i + 1);
            } else {
                datas[i] = i + 1 + "";
            }


        }
        return datas;


    }


}
